@@ -17,8 +17,6 @@ from __future__ import unicode_literals
 import os.path
 import re
 
-import six
-
 from werkzeug.exceptions import NotFound
 from werkzeug.security import safe_join
 from werkzeug.wsgi import wrap_file
@@ -72,7 +70,7 @@ def project(app, request, project_name):
 
         # Generate the Homepage and Download URL links
         release_urls = app.models.packaging.get_release_urls(project.name)
-        for version, (home_page, download_url) in six.iteritems(release_urls):
+        for version, (home_page, download_url) in release_urls.items():
             if home_page and home_page != "UNKNOWN":
                 project_urls.append({
                     "rel": home_rel,
@@ -144,7 +142,8 @@ def package(app, request, path):
         raise NotFound("{} was not found".format(filename))
 
     # Get the project name and normalize it
-    project = app.models.packaging.get_project_for_filename(filename)
+    lookup_filename = filename[:-4] if filename.endswith(".asc") else filename
+    project = app.models.packaging.get_project_for_filename(lookup_filename)
     normalized = re.sub("_", "-", project.name, re.I).lower()
 
     # Get the MD5 hash of the file
@@ -180,11 +179,12 @@ def package(app, request, path):
     # Setup the Content-Length header
     resp.content_length = os.path.getsize(filepath)
 
-    # Setup the Content-MD5 headers
-    resp.content_md5 = content_md5
+    if content_md5:
+        # Setup the Content-MD5 headers
+        resp.content_md5 = content_md5
 
-    # Setup Conditional Responses
-    resp.set_etag(content_md5)
-    resp.make_conditional(request)
+        # Setup Conditional Responses
+        resp.set_etag(content_md5)
+        resp.make_conditional(request)
 
     return resp
